function    g = lfmGradientH(gamma1, gamma2, sigma2, gradThetaGamma, t1, t2)

% LFMGRADIENTH Gradient of the function h_i(z) with respect to some of the
%
%	Description:
%	hyperparameters of the kernel: m_k, C_k, D_k, m_r, C_r or D_r.
%
%	G = LFMGRADIENTH(GAMMA1, GAMMA2, SIGMA2, GRADTHETAGAMMA, T1, T2)
%	Computes the gradient of the function h_i(z) with respect to some of
%	the parameters of the system (mass, spring or damper).
%	 Returns:
%	  G - Gradient of the function with respect to the desired
%	   parameter.
%	 Arguments:
%	  GAMMA1 - Gamma value for first system.
%	  GAMMA2 - Gamma value for second system.
%	  SIGMA2 - length scale of latent process.
%	  GRADTHETAGAMMA - Vector with the gradient of gamma1 and gamma2
%	   with respect to the desired parameter.
%	  T1 - first time input (number of time points x 1).
%	  T2 - second time input (number of time points x 1).
%	
%	
%
%	See also
%	LFMKERNGRADIENT, LFMXLFMKERNGRADIENT, LFMGRADIENTUPSILON


%	Copyright (c) 2007 David Luengo


%	With modifications by David Luengo 2008
% 	lfmGradientH.m SVN version 11
% 	last update 2008-06-05T18:41:50.000000Z


% Creation of the time matrices

Tt1 = repmat(t1,1,size(t2, 1));
Tt2 = repmat(t2',size(t1, 1),1);

% Gradient evaluation

g = (lfmGradientUpsilon(gamma1,sigma2,gradThetaGamma(1),Tt2,Tt1) ...
    + gradThetaGamma(2)*Tt1.*exp(-gamma2*Tt1) ...
    .* lfmComputeUpsilon(gamma1,sigma2,Tt2,zeros(size(Tt1))) - exp(-gamma2*Tt1) ...
    .* lfmGradientUpsilon(gamma1,sigma2,gradThetaGamma(1),Tt2,zeros(size(Tt1))) ...
    - sum(gradThetaGamma)*lfmComputeH(gamma1,gamma2,sigma2,t1,t2))/(gamma1+gamma2);
